@@ -1,7 +1,6 @@
 from .between import between
 from .email import email
 from .extremes import Min, Max
-from .finnish_business_id import finnish_business_id
 from .ip_address import ipv4, ipv6
 from .length import length
 from .mac_address import mac_address
@@ -9,12 +8,14 @@ from .truthy import truthy
 from .url import url
 from .utils import ValidationFailure, validator
 from .uuid import uuid
+from .i18n import fi_business_id, fi_ssn
 
 
 __all__ = (
     between,
     email,
-    finnish_business_id,
+    fi_business_id,
+    fi_ssn,
     ipv4,
     ipv6,
     length,
@@ -29,4 +30,4 @@ __all__ = (
 )
 
 
-__version__ = '0.4'
+__version__ = '0.5'
