@@ -8,7 +8,7 @@ user_regex = re.compile(
     r"(\.[-!#$%&'*+/=?^_`{}|~0-9A-Z]+)*$"
     # quoted-string
     r'|^"([\001-\010\013\014\016-\037!#-\[\]-\177]|'
-    r'\\[\001-\011\013\014\016-\177])*"$)',
+    r"""\\[\001-\011\013\014\016-\177])*"$)""",
     re.IGNORECASE
 )
 domain_regex = re.compile(
